class ABC:
    pass


def abstractmethod(f):
    return f
